# hearth

a collection tools and extensions for working with pytorch

----
[![pypi version](https://img.shields.io/pypi/v/hearth.svg)](https://pypi.python.org/pypi/hearth)
[![build](https://github.com/leaprovenzano/hearth/workflows/CI/badge.svg)](https://github.com/leaprovenzano/hearth/actions)
[![documentation status](https://readthedocs.org/projects/hearth/badge/?version=latest)](https://hearth.readthedocs.io/en/latest/?badge=latest)
[![coverage](https://codecov.io/gh/leaprovenzano/hearth/branch/main/graph/badge.svg)](https://codecov.io/gh/leaprovenzano/hearth/branch/main/graph/badge.svg)

------------------------------------------------------------------------

-   *Free software*: MIT license
-   *Documentation*: [docs](https://hearth.readthedocs.io)
-   *Supported Python Versions*: >=3.7

------------------------------------------------------------------------

## Getting Started:


Install the latest stable version with pip:

    $ pip install hearth

---
## Checkout the docs:

It's best to checkout the [docs](https://hearth.readthedocs.io). There you'll find detailed
documentation of hearth's features and lots of examples of how to
use them.
